@@ -1,5 +1,5 @@
 #
-# google_cloud_tts.py <Peter.Bienstman@UGent.be>
+# responsive_voice_tts.py <Peter.Bienstman@UGent.be>
 #
 
 # Set up your account according to
@@ -19,7 +19,7 @@ from mnemosyne.libmnemosyne.pronouncer import Pronouncer
 
 class GoogleCloudPronouncer(Pronouncer):
 
-    used_for = "en", "en-GB", "en-US", "fr", "fr-FR", "ar"
+    used_for = "en", "en-GB", "en-US", "fr", "fr-FR", "ar", "it"
 
     popup_menu_text = "Insert Google Cloud text-to-speech..."
 
@@ -33,14 +33,25 @@ class GoogleCloudPronouncer(Pronouncer):
             language_id = self.config().card_type_property(\
                 "language_id", card_type)
 
+        if " ج " in foreign_text:
+            singular, plural = foreign_text.split(" ج ")
+            foreign_text = \
+                f"""<speak>{singular}<break time="0.3s"/>{plural}</speak>"""
+        if "<br>" in foreign_text:
+            foreign_text = "<speak>" + \
+                foreign_text.replace("<br>", """<break time="0.3s"/>""") +\
+                "</speak>"
         client = texttospeech.TextToSpeechClient()
-        synthesis_input = texttospeech.types.SynthesisInput(ssml=foreign_text)
-        voice = texttospeech.types.VoiceSelectionParams(
+        synthesis_input = texttospeech.SynthesisInput(ssml=foreign_text)
+        voice = texttospeech.VoiceSelectionParams(
             language_code=language_id,
-            ssml_gender=texttospeech.enums.SsmlVoiceGender.FEMALE)
-        audio_config = texttospeech.types.AudioConfig(
-            audio_encoding=texttospeech.enums.AudioEncoding.MP3)
-        response = client.synthesize_speech(synthesis_input, voice, audio_config)
+            ssml_gender=texttospeech.SsmlVoiceGender.FEMALE)
+        audio_config = texttospeech.AudioConfig(
+            audio_encoding=texttospeech.AudioEncoding.MP3)
+        response = client.synthesize_speech(request={
+            "input": synthesis_input,
+            "voice": voice,
+            "audio_config": audio_config})
 
         filename = expand_path("__GTTS__TMP__.mp3", self.database().media_dir())
         with open(filename, 'wb') as mp3_file:
